@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KIMAP_QUOTAJOBBASE_P_H
-#define KIMAP_QUOTAJOBBASE_P_H
+#pragma once
 
 #include "job_p.h"
 #include "response_p.h"
@@ -32,4 +31,3 @@ public:
 };
 }
 
-#endif
