@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KIMAP_SUBSCRIBEJOB_H
-#define KIMAP_SUBSCRIBEJOB_H
+#pragma once
 
 #include "kimap_export.h"
 
@@ -13,7 +12,6 @@
 
 namespace KIMAP
 {
-
 class Session;
 class SubscribeJobPrivate;
 
@@ -37,4 +35,3 @@ protected:
 
 }
 
-#endif
